import { createTranslator, } from './translator';
export * from './translator';
const mergedCache = [];
// eslint-disable-next-line sonar/function-name
const VueTranslator = ($Vue, options) => {
    if (typeof options === 'string') {
        options = {
            locale: options,
        };
    }
    const { defaultLocale, locale, merge, translations = {} } = options;
    const defaultTranslator = createTranslator({
        locale,
        translations,
        defaultLocale,
    });
    $Vue.translator = defaultTranslator;
    $Vue.mixin({
        beforeCreate() {
            const { translator } = this.$options;
            // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
            const { cid } = Object.getPrototypeOf(this).constructor;
            if (!translator || mergedCache.indexOf(cid) + 1) {
                return;
            }
            if (!merge) {
                // istanbul ignore next
                if (process.env.NODE_ENV === 'development') {
                    $Vue.util.warn('VueTranslator will not help you to merge translations, please pass your own merge strategy, `lodash.merge` for example');
                }
                return;
            }
            merge(translations, translator);
            mergedCache.push(cid);
        },
    });
    Object.defineProperty($Vue.prototype, '$t', process.env.VUE_ENV === 'server'
        ? {
            get() {
                const { translator } = this.$ssrContext;
                if (process.env.NODE_ENV === 'development' && !translator) {
                    $Vue.util.warn('there is no translator instance on ssrContext, you should register it manually');
                }
                return translator || defaultTranslator;
            },
            configurable: process.env.NODE_ENV === 'development',
        }
        : {
            value: defaultTranslator,
            writable: process.env.NODE_ENV === 'development',
        });
    let { filter } = options;
    if (!filter) {
        return;
    }
    if (filter === true) {
        filter = 'translate';
    }
    if (process.env.VUE_ENV !== 'server') {
        $Vue.filter(filter, defaultTranslator);
        return;
    }
    const { _f } = $Vue.prototype;
    // a hacky way to support filter on server, so `filter` is not enabled by default
    // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
    $Vue.prototype._f = function (id) {
        var _a;
        if (process.env.NODE_ENV === 'development' &&
            ((_a = this.$options.filters) === null || _a === void 0 ? void 0 : _a[filter])) {
            $Vue.util.warn(`duplicate filter \`${filter}\` found, please rename to a unique filter name`);
        }
        return id === filter ? this.$t : _f.call(this, id);
    };
};
export default VueTranslator;
export const install = VueTranslator;
//# sourceMappingURL=index.js.map