(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.VueTranslator = {}, global.Vue));
}(this, (function (exports, Vue) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var Vue__default = /*#__PURE__*/_interopDefaultLegacy(Vue);

  var LOCALE = 'locale';
  var DEFAULT_LOCALE = 'defaultLocale';
  var defineReactive = Vue__default['default'].util.defineReactive;
  var translations;
  var getValue = function (input, key) {
      key = key.replace(/\[(\d+)]/g, '.$1');
      var value = input;
      // eslint-disable-next-line array-callback-return
      key.split('.').some(function (k) {
          if (!value || typeof value !== 'object') {
              return true;
          }
          value = value[k];
      });
      if (typeof value === 'object') {
          // istanbul ignore next
          if (process.env.NODE_ENV === 'development' && value !== null) {
              Vue__default['default'].util.warn('you are trying to get non-literal value');
          }
          return value && String(value);
      }
      return value;
  };
  var createTranslator = function (translatorOptions) {
      if (typeof translatorOptions === 'string') {
          translatorOptions = { locale: translatorOptions };
      }
      var instanceLocale = translatorOptions.locale, instanceTranslations = translatorOptions.translations, instanceDefaultLocale = translatorOptions.defaultLocale;
      if (instanceTranslations) {
          // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
          if (!translations) {
              translations = instanceTranslations;
          }
          // istanbul ignore next
          else if (process.env.NODE_ENV === 'development' &&
              translations !== instanceTranslations) {
              Vue__default['default'].util.warn('translations should only be injected once!');
          }
          // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
      }
      else if (process.env.NODE_ENV === 'development' && !translations) {
          Vue__default['default'].util.warn('translations has not be injected, translator will not work!');
      }
      var instance = function (key, params, ignoreNonExist) {
          var locale = instance.locale;
          var translation = translations[locale];
          var value = getValue(translation, key);
          if (value === undefined) {
              var defaultLocale = instance.defaultLocale;
              if (defaultLocale && defaultLocale !== locale) {
                  var defaultTranslation = translations[defaultLocale];
                  value = getValue(defaultTranslation, key);
              }
              if (process.env.NODE_ENV === 'development' &&
                  value === undefined &&
                  !ignoreNonExist) {
                  Vue__default['default'].util.warn("your are trying to get nonexistent key `" + key + "` without default locale fallback");
              }
          }
          value = value === null || value === void 0 ? void 0 : value.replace(/{([^{}]+)}/g, function (_matched, $0) { return getValue(params, $0.trim()); });
          return value == null ? key : value;
      };
      defineReactive(instance, LOCALE, instanceLocale);
      defineReactive(instance, DEFAULT_LOCALE, instanceDefaultLocale);
      return instance;
  };

  var mergedCache = [];
  // eslint-disable-next-line sonar/function-name
  var VueTranslator = function ($Vue, options) {
      if (typeof options === 'string') {
          options = {
              locale: options,
          };
      }
      var defaultLocale = options.defaultLocale, locale = options.locale, merge = options.merge, _a = options.translations, translations = _a === void 0 ? {} : _a;
      var defaultTranslator = createTranslator({
          locale: locale,
          translations: translations,
          defaultLocale: defaultLocale,
      });
      $Vue.translator = defaultTranslator;
      $Vue.mixin({
          beforeCreate: function () {
              var translator = this.$options.translator;
              // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
              var cid = Object.getPrototypeOf(this).constructor.cid;
              if (!translator || mergedCache.indexOf(cid) + 1) {
                  return;
              }
              if (!merge) {
                  // istanbul ignore next
                  if (process.env.NODE_ENV === 'development') {
                      $Vue.util.warn('VueTranslator will not help you to merge translations, please pass your own merge strategy, `lodash.merge` for example');
                  }
                  return;
              }
              merge(translations, translator);
              mergedCache.push(cid);
          },
      });
      Object.defineProperty($Vue.prototype, '$t', process.env.VUE_ENV === 'server'
          ? {
              get: function () {
                  var translator = this.$ssrContext.translator;
                  if (process.env.NODE_ENV === 'development' && !translator) {
                      $Vue.util.warn('there is no translator instance on ssrContext, you should register it manually');
                  }
                  return translator || defaultTranslator;
              },
              configurable: process.env.NODE_ENV === 'development',
          }
          : {
              value: defaultTranslator,
              writable: process.env.NODE_ENV === 'development',
          });
      var filter = options.filter;
      if (!filter) {
          return;
      }
      if (filter === true) {
          filter = 'translate';
      }
      if (process.env.VUE_ENV !== 'server') {
          $Vue.filter(filter, defaultTranslator);
          return;
      }
      var _f = $Vue.prototype._f;
      // a hacky way to support filter on server, so `filter` is not enabled by default
      // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
      $Vue.prototype._f = function (id) {
          var _a;
          if (process.env.NODE_ENV === 'development' &&
              ((_a = this.$options.filters) === null || _a === void 0 ? void 0 : _a[filter])) {
              $Vue.util.warn("duplicate filter `" + filter + "` found, please rename to a unique filter name");
          }
          return id === filter ? this.$t : _f.call(this, id);
      };
  };
  var install = VueTranslator;

  exports.createTranslator = createTranslator;
  exports.default = VueTranslator;
  exports.install = install;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
